# Shellwrapper

Simple object allowing to run commands and log their ouput with a custom logger.

## Examples:

### Run with default

```python
from shellwrapper.shell import Shell

shell = Shell()

# Just print
shell.run("echo Lorem Ipsum...", quiet=False, capture_output=False)

>>> echo Lorem ipsum dolor sit amet
    ...

# Just capture
out = shell.run("echo Lorem Ipsum...", quiet=False, capture_output=True)

# Just run
shell.run("echo Lorem Ipsum...", quiet=True, capture_output=False)

# Print and capture
out = shell.run("echo Lorem Ipsum...", quiet=False, capture_output=True)

>>> echo Lorem ipsum dolor sit amet
    ...

out.stdout == "Lorem ipsum dolor sit amet..."
```

### Run with custom logger (styling with Rich)

```python
import logging

from shellwrapper.shell import Shell
from shellwrapper.logging.style import TextStyle
from shellwrapper.logging.logging import LoggerStyle, getLogger
from shellwrapper.logging.handlers.rich import RichHandler

custom_style = TextStyle(
    indentation=5,
    color="blue",
    background_color=None,
    bold=True,
    italic=False,
    underline=True,
    strikethrough=False,
) # All arguments are optional

logger_style = LoggerStyle(
    debug=custom_style,
    info=custom_style,
    warn=custom_style,
    error=custom_style,
    critical=custom_style,
    in_evidence=custom_style,
    stdout=custom_style,
    stderr=custom_style,
) # All arguments are optional

logger = getLogger()
logger.setLevel(logging.INFO)
logger.setStyle(logger_style)
handler = RichHandler(level=logging.INFO)
logger.addHandler()

shell = Shell(logger=logger)
shell.run("echo 'blue commands and stdout!'")
>>> <span style="color:blue"><strong>echo 'blue commands and stdout!'</strong></span>
    <span style="color:blue"><strong>blue commands and stdout!</strong></span>
```

This gives the possibility of easily configuring the logger style for different shells. 