#
# Author: Francesco Talpo
#
# This file is part of Shellwrapper.
#
# Shellwrapper is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.
#
# Shellwrapper is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Shellwrapper. If not, see <https://www.gnu.org/licenses/>.
#


import logging

from rich.text import Text
from rich.console import Console
from rich.style import Style

from ...style import STYLE_KEY, TextStyle


def stylize_record(
    formatted: str, record: logging.LogRecord, text_style: TextStyle
) -> Text:
    msg = Text(formatted)
    if text_style:
        if text_style.indentation:
            msg.pad_left(text_style.indentation)
        style = Style(
            color=text_style.color,
            bgcolor=text_style.background_color,
            bold=text_style.bold,
            underline=text_style.underline,
            italic=text_style.italic,
            strike=text_style.strikethrough,
        )
        msg.stylize(
            style,
            formatted.index(record.msg) + text_style.indentation,
            formatted.index(record.msg) + len(record.msg) + text_style.indentation,
        )
    return msg


class RichHandler(logging.Handler):

    def __init__(
        self, level: logging._Level = logging.NOTSET, console: Console | None = None
    ) -> None:
        self.console = console or Console()
        super().__init__(level)

    def emit(self, record: logging.LogRecord) -> None:
        msg = self.format(record)
        if style := getattr(record, STYLE_KEY, None):
            formatted = stylize_record(msg, record, style)
        else:
            formatted = Text(msg)

        self.console.print(formatted)
